----------------------------------------------------------------------------------
-- Company: University of Ljubljana, Faculty of Electrical Engineering
-- Engineer: Andrej Trost
-- 
-- Create Date: 03/10/2015 01:15:47 PM
-- Design Name: Red Pitaya Logic I/F
-- Module Name: rp_vmes
-- Project Name: http://www.redpitaya.com
-- Description: 
-- 
-- Revision: 1
----------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.NUMERIC_STD.ALL;

entity rp_vmesnik is
    Port ( clk50 : in STD_LOGIC;             -- sampling clock
           extclk: in STD_LOGIC;             -- ext clock, currenty unused           
           data : in STD_LOGIC_VECTOR (7 downto 0); -- ext data
           led : out STD_LOGIC_VECTOR (3 downto 0); -- RP status LED
           
           adrout : in STD_LOGIC_VECTOR (7 downto 0); -- BRAM interface
           dataout: out STD_LOGIC_VECTOR (7 downto 0);
           
           logox: out STD_LOGIC_VECTOR (7 downto 0); -- to VGA
           
           -- System bus
           clk_i:   in STD_LOGIC;                      -- bus clock 
           rstn_i:  in STD_LOGIC;                      -- bus reset - active low
           adr_i:   in STD_LOGIC_VECTOR(31 downto 0);  -- bus address
           wdata_i: in STD_LOGIC_VECTOR(31 downto 0);  -- bus write data          
           wen_i:   in STD_LOGIC;                      -- bus write enable
           rdata_o: out STD_LOGIC_VECTOR(31 downto 0); -- bus read data
           err_o:   out STD_LOGIC;                     -- bus error indicator
           ack_o:   out STD_LOGIC                      -- bus acknowledge signal         
           );
end rp_vmesnik;

architecture Behavioral of rp_vmesnik is
  type mem is array(0 to 255) of std_logic_vector(7 downto 0);
  signal ram: mem;
  signal start_i: std_logic := '0';
  signal a: unsigned(7 downto 0) := (others=>'0');
  
  type stanja is (mir, cakaj, shrani, konec);
  signal st: stanja;
  
  signal wr, start1, start2: std_logic;  
  signal komb_i, komb, maska_i, maska: std_logic_vector(7 downto 0);
  signal datamask, kombmask, sample: std_logic_vector(7 downto 0);
  
begin

 kombmask <= komb and maska; -- maskiranje kombinacije in podatka
 datamask <= sample and maska;

p1: process(clk50) begin  
 if rising_edge(clk50) then   
   maska<= maska_i;          -- sinhronizacija
   komb<=komb_i;
   start1<=start_i;
   start2<=start1;
   sample <= data;           -- vzornje
   
   dataout <= ram(to_integer(unsigned(adrout))); -- branje BRAM
   if wr='1' then -- vpis v BRAM
      ram(to_integer(a)) <= data;
      a <= a + 1;
   end if;

   wr <= '0';
   case st is
    when mir =>               
        if start1='1' and start2='0' then  -- fronta signala start
            st<=cakaj;
            a <= (others=>'0');
        end if;
        
    when cakaj =>  
        if datamask = kombmask then  -- pogoj za proenje, pojdi na shranjevanje
           st <= shrani;
           wr <= '1';
        end if;
        
    when shrani =>  -- shrani v BRAM 128 podatkov   
        if a=127 then
            st <= konec;
        else
            wr <= '1';
        end if;
        
   when konec =>
        st <= mir;
  end case;
              
 end if;
end process;

led <= "0110";

-- bus interface logic
pbus: process(clk_i)
begin
 if rising_edge(clk_i) then   
   if wen_i='1' then -- pisanje v registre na naslovu 0x4060
     start_i <= '0';
     if adr_i(19 downto 0) = X"00000" then -- vpis kombinacije in start
        komb_i <= wdata_i(7 downto 0);
        start_i <= '1';
     elsif adr_i(19 downto 0) = X"00004" then -- vpis maske
        maska_i <= wdata_i(7 downto 0);
     elsif adr_i(19 downto 0) = X"00008" then -- vpis pozicije / zoom     
       logox <= wdata_i(7 downto 0); 
     end if;
   end if;
 end if;
end process;

err_o <= '0';
rdata_o <= (others=>'0'); ack_o <= '1';

--pbusr: process(adr_i, mode, scale, vert1, vert2)
--begin   
--  case adr_i(19 downto 0) is
--    when X"00000" => rdata_o <= X"000000" & "000" & mode; ack_o <= '1';
--    when X"00010" => rdata_o <= X"0000000" & '0' & std_logic_vector(scale); ack_o <= '1';
--    when X"00014" => rdata_o <= X"0000000" & '0' & std_logic_vector(vert1); ack_o <= '1';
--    when X"00018" => rdata_o <= X"0000000" & '0' & std_logic_vector(vert2); ack_o <= '1';    
--    when others => rdata_o <= (others=>'0'); ack_o <= '1';  
--  end case;
----  rdata_o <= (others=>'0'); ack_o <= '1';
--end process;

end Behavioral;
